## ---- include=FALSE-----------------------------------------------------------
library(lingtypology)

## -----------------------------------------------------------------------------
names(glottolog)

## -----------------------------------------------------------------------------
iso.lang("Adyghe")
lang.iso("ady")
lang.aff("West Caucasian")

## -----------------------------------------------------------------------------
area.lang(c("Adyghe", "Aduge"))
lang <- c("Adyghe", "Russian")
aff.lang(lang)

## -----------------------------------------------------------------------------
iso.lang(lang.aff("Circassian"))

## -----------------------------------------------------------------------------
aff.lang("Adyge")

## -----------------------------------------------------------------------------
subc.lang("Lechitic")

## -----------------------------------------------------------------------------
library(ape)
plot(read.tree(text = subc.lang("Lechitic")))

## -----------------------------------------------------------------------------
plot(read.tree(text = subc.lang("Lechitic")),
     tip.color = c("red", "black", "black", "black"))

